@@ -1,5 +1,6 @@
 from datetime import date, datetime
 from decimal import Decimal
+from functools import cached_property
 from typing import TYPE_CHECKING, Iterable, Protocol, runtime_checkable
 from zoneinfo import ZoneInfo
 
@@ -15,14 +16,13 @@ from pykis.api.stock.market import (
     KisMarketType,
     get_market_code,
     get_market_code_timezone,
-    get_market_timezone,
 )
 from pykis.client.account import KisAccountNumber
 from pykis.client.page import KisPage
 from pykis.responses.dynamic import KisDynamic, KisList, KisTransform
 from pykis.responses.response import KisPaginationAPIResponse
-from pykis.responses.types import KisAny, KisDecimal, KisInt, KisString
-from pykis.utils.cache import cached
+from pykis.responses.types import KisAny, KisDecimal, KisString
+from pykis.utils.math import safe_divide
 from pykis.utils.repr import kis_repr
 from pykis.utils.timezone import TIMEZONE
 
@@ -230,7 +230,7 @@ class KisOrderProfitBase(KisOrderProfitRepr, KisAccountProductBase):
     @property
     def profit_rate(self) -> Decimal:
         """손익률 (-100 ~ 100)"""
-        return (self.profit / self.buy_amount) * 100
+        return safe_divide(self.profit, self.buy_amount) * 100
 
     exchange_rate: Decimal
     """당일환율"""
@@ -438,9 +438,9 @@ class KisForeignOrderProfits(KisPaginationAPIResponse, KisOrderProfitsBase):
     _end: date
     _country: COUNTRY_TYPE | None = None
 
-    @property
-    @cached
-    def fees(self) -> Decimal:
+    # Pylance bug: cached_property[Decimal] type inference error.
+    @cached_property
+    def fees(self) -> Decimal:  # type: ignore
         """
         수수료 조회 (모의투자 미지원)
 
@@ -454,6 +454,8 @@ class KisForeignOrderProfits(KisPaginationAPIResponse, KisOrderProfitsBase):
             country=self._country,
         )
 
+    fees: Decimal
+
     def __init__(
         self,
         account_number: KisAccountNumber,
