@@ -42,97 +42,97 @@ class KisRealtimeExecution(KisWebsocketResponseProtocol, Protocol):
     @property
     def time(self) -> datetime:
         """주문시각"""
-        raise NotImplementedError
+        ...
 
     @property
     def time_kst(self) -> datetime:
         """주문시각(KST)"""
-        raise NotImplementedError
+        ...
 
     @property
     def timezone(self) -> ZoneInfo:
         """시간대"""
-        raise NotImplementedError
+        ...
 
     @property
     def order_number(self) -> KisOrderNumber:
         """주문번호"""
-        raise NotImplementedError
+        ...
 
     @property
     def type(self) -> ORDER_TYPE:
         """주문유형"""
-        raise NotImplementedError
+        ...
 
     @property
     def price(self) -> Decimal:
         """체결단가"""
-        raise NotImplementedError
+        ...
 
     @property
     def unit_price(self) -> Decimal | None:
         """주문단가"""
-        raise NotImplementedError
+        ...
 
     @property
     def order_price(self) -> Decimal | None:
         """주문단가"""
-        raise NotImplementedError
+        ...
 
     @property
     def quantity(self) -> ORDER_QUANTITY:
         """주문수량"""
-        raise NotImplementedError
+        ...
 
     @property
     def qty(self) -> ORDER_QUANTITY:
         """주문수량"""
-        raise NotImplementedError
+        ...
 
     @property
     def executed_quantity(self) -> ORDER_QUANTITY:
         """체결수량"""
-        raise NotImplementedError
+        ...
 
     @property
     def executed_qty(self) -> ORDER_QUANTITY:
         """체결수량"""
-        raise NotImplementedError
+        ...
 
     @property
     def executed_amount(self) -> Decimal:
         """체결금액"""
-        raise NotImplementedError
+        ...
 
     @property
     def condition(self) -> ORDER_CONDITION | None:
         """주문조건"""
-        raise NotImplementedError
+        ...
 
     @property
     def execution(self) -> ORDER_EXECUTION | None:
         """체결조건"""
-        raise NotImplementedError
+        ...
 
     @property
     def receipt(self) -> bool:
         """접수여부"""
-        raise NotImplementedError
+        ...
 
     @property
     def canceled(self) -> bool:
         """취소여부 (IOC/FOK)"""
-        raise NotImplementedError
+        ...
 
     @property
     def rejected(self) -> bool:
         """거부여부"""
-        raise NotImplementedError
+        ...
 
     @property
     def rejected_reason(self) -> str | None:
         """거부사유"""
-        raise NotImplementedError
+        ...
 
 
 @kis_repr(
@@ -392,7 +392,9 @@ class KisForeignRealtimeOrderExecution(KisRealtimeExecutionBase):
         None,  # 12 CNTG_YN 체결여부 1:주문,정정,취소,거부 2:체결
         None,  # 13 ACPT_YN 접수여부 1:주문접수 2:확인 3:취소(FOK/IOC)
         None,  # 14 BRNC_NO 지점번호
-        KisDecimal["quantity"],  # 15 ODER_QTY 주문수량
+        KisDecimal[
+            "quantity", Decimal(-1)
+        ],  # 15 ODER_QTY 주문수량, 주문통보인 경우 해당 위치 미출력 (주문통보의 주문수량은 CNTG_QTY 위치에 출력). 체결통보인 경우 해당 위치에 주문수량이 출력
         None,  # 16 ACNT_NAME 계좌명
         None,  # 17 CNTG_ISNM 체결종목명
         KisAny(FOREIGN_MARKET_CODE_MAP.__getitem__)[
@@ -469,6 +471,9 @@ class KisForeignRealtimeOrderExecution(KisRealtimeExecutionBase):
         self.timezone = get_market_timezone(self.market)
         self.time = self.time_kst.astimezone(self.timezone)
 
+        if self.quantity < 0:
+            self.quantity = self.executed_quantity
+
         if self.receipt:
             self.quantity = self.executed_quantity
             self.executed_quantity = ORDER_QUANTITY(0)
